@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-12-15 11:44:37
+@LastEditTime: 2022-01-10 14:38:30
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -127,7 +127,7 @@ class FrameBaseHandler(BaseApiHandler):
 
     def _convert_request_params(self):
         """
-        :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数
+        :Description: 转换请求参数 post请求：Content-type必须为application/json，前端必须对对象进行序列化转成json字符串，不能直接传对象,否则无法接收参数,存在特殊字符的参数必须进行url编码，否则+会被变成空值
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
@@ -225,7 +225,10 @@ class FrameBaseHandler(BaseApiHandler):
             if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
                 dv = SevenHelper.get_random(16)
                 encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
-                app_id = self.get_argument("source_app_id", "", strip=True)
+                if self.get_argument("app_id", "", strip=True):
+                    app_id = self.get_argument("app_id", "", strip=True)
+                else:
+                    app_id = self.get_argument("source_app_id", "", strip=True)
                 if not app_id:
                     app_id = config.get_value("app_id")
                 password = str(encrypt_key).replace("1", "l")
