@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2021-12-07 19:03:20
+@LastEditTime: 2021-12-29 15:32:27
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
@@ -212,4 +212,27 @@ class CmsInfoListHandler(ClientBaseHandler):
         cms_base_model = CmsBaseModel(context=self)
         page_list, total = self.business_process_executed(cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False), ref_params={})
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
-        return self.response_json_success(page_info)
\ No newline at end of file
+        return self.response_json_success(page_info)
+
+
+class GetProductPriceHandler(ClientBaseHandler):
+    """
+    :description: 获取产品价格信息
+    """
+    def get_async(self):
+        """
+        :description: 获取产品价格信息
+        :return 
+        :last_editors: HuangJianYi
+        """
+        product_price_model = ProductPriceModel(context=self)
+        now_date = SevenHelper.get_now_datetime()
+        product_price = product_price_model.get_dict(where="%s>=begin_time and %s<=end_time and is_release=1", order_by="create_time desc", params=[now_date, now_date])
+        if not product_price:
+            return self.response_json_error("error", "找不到产品价格信息")
+        try:
+            product_price["content"] = SevenHelper.json_loads(product_price["content"])
+        except:
+            return self.response_json_error("error", "产品价格信息格式有误")
+
+        return self.reponse_json_success(product_price)
\ No newline at end of file
