@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-12-29 11:13:45
+@LastEditTime: 2021-12-30 14:09:13
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -46,18 +46,15 @@ class PayOrderListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         if main_pay_order_no:
             condition += " and " if condition else ""
@@ -122,18 +119,15 @@ class PrizeOrderListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 20))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
         page_info = order_base_model.get_prize_order_list(app_id, act_id, user_id, user_open_id, user_nick, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, field=field, is_search_roster=is_search_roster, is_cache=False, condition=condition, params=params)
@@ -186,18 +180,15 @@ class PrizeRosterListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
 
-        condition = ""
-        params = []
-        order_by ="create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success({"data": []})
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         order_base_model = OrderBaseModel(context=self)
         page_info = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False)
         ref_params = {}
@@ -341,18 +332,15 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success("")
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = []
@@ -458,18 +446,15 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success("")
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = []
@@ -552,18 +537,15 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 500))
 
-        condition = ""
-        params = []
-        order_by = "create_date desc"
-        field = "*"
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_success("")
-        else:
-            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
-            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
-            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
-            field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+        order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
+        field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
 
         if main_pay_order_no:
             condition += " and " if condition else ""
