@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-12-27 16:35:22
+@LastEditTime: 2022-01-07 15:43:42
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -493,4 +493,16 @@ class SevenHelper:
         if not sub_count:
             return sub_table
         sub_table = str(object_id % sub_count)
-        return sub_table
\ No newline at end of file
+        return sub_table
+
+    @classmethod
+    def remove_exponent(self, param):
+        """
+        :description: 去除参数多余的0，比如：100.00返回100，100.10返回100.1去掉尾数0
+        :param param:要去除0的参数
+        :return:
+        :last_editors: HuangJianYi
+        """
+        if isinstance(param, str):
+            param = decimal.Decimal(param)
+        return param.to_integral() if param == param.to_integral() else param.normalize()
\ No newline at end of file
