@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2021-09-06 17:33:46
+@LastEditTime: 2021-11-25 11:14:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -151,7 +151,7 @@ class ActBaseModel():
         self._delete_act_info_dependency_key(app_id,act_info.id)
         return invoke_result_data
 
-    def update_act_info(self,app_id,act_id,act_name,theme_id,is_share,share_desc_json,is_rule,rule_desc_json,is_release,start_date,end_date,is_black,refund_count,join_ways,is_fictitious,close_word="抱歉，程序维护中",store_url=None,i1=-1,i2=-1,i3=-1,i4=-1,i5=-1,s1=None,s2=None,s3=None,s4=None,s5=None,d1=None,d2=None):
+    def update_act_info(self,app_id,act_id,act_name,theme_id,is_share,share_desc_json,is_rule,rule_desc_json,is_release,start_date,end_date,is_black,refund_count,join_ways,is_fictitious,close_word="抱歉，程序维护中",store_url=None,i1=-1,i2=-1,i3=-1,i4=-1,i5=-1,s1=None,s2=None,s3=None,s4=None,s5=None,d1=None,d2=None,is_visit_store=-1):
         """
         :description: 修改活动信息
         :param app_id: 应用标识
@@ -182,6 +182,7 @@ class ActBaseModel():
         :param s5: s5
         :param d1: d1
         :param d2: d2
+        :param is_visit_store: 是否开启访问店铺
         :return: 
         :last_editors: HuangJianYi
         """
@@ -226,6 +227,8 @@ class ActBaseModel():
             act_info.is_fictitious = is_fictitious
         if close_word !=None:
             act_info.close_word = close_word
+        if is_visit_store !=-1:
+            act_info.is_visit_store = is_visit_store
         if store_url !=None:
             act_info.store_url = store_url
         if i1 !=-1:
