@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-12-07 15:26:38
+@LastEditTime: 2021-12-21 10:24:23
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -21,7 +21,7 @@ class AssetBaseModel():
     def __init__(self, context, logging_error=None):
         self.context = context
         self.logging_link_error = logging_error
-    
+
     def _delete_asset_dependency_key(self,act_id,user_id):
         """
         :description: 删除资产依赖建
@@ -47,17 +47,17 @@ class AssetBaseModel():
         if handler_name:
             handler_name = str(handler_name).lower()
             redis_init = SevenHelper.redis_init()
-            
+
             hash_name_1 = f"warn_handler_list_{str(SevenHelper.get_now_int(fmt='%Y%m%d'))}"
             hash_key_1 = f"handlername_{handler_name}"
             if not redis_init.hexists(hash_name_1, hash_key_1):
                 redis_init.hset(hash_name_1,hash_key_1,SevenHelper.json_dumps({"app_id":'',"handler_name":handler_name}))
                 redis_init.expire(hash_name_1, 24 * 3600)
-            
+
             hash_name_2 = f"{hash_name_1}:{hash_key_1}"
             redis_init.hincrby(hash_name_2, str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M')), 1)
             redis_init.expire(hash_name_2, 24 * 3600)
-  
+
     def get_user_asset_id_md5(self, act_id, user_id, asset_type, asset_object_id):
         """
         :description: 生成用户资产唯一标识
@@ -352,7 +352,7 @@ class AssetBaseModel():
                 user_asset_dict["asset_value"] = 0
         return user_asset_dict
 
-    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*",is_cache=True):
+    def get_asset_log_list(self, app_id, act_id, asset_type, page_size=20, page_index=0, user_id=0, asset_object_id="", start_date="", end_date="", user_nick="", open_id="", source_type=0, source_object_id=None, field="*", is_cache=True, operate_type=-1):
         """
         :description: 获取用户资产流水记录
         :param app_id：应用标识
@@ -370,6 +370,7 @@ class AssetBaseModel():
         :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
         :param field：查询字段
         :param is_cache：是否缓存
+        :param operate_type：操作类型 （0累计 1消耗）
         :return: 返回PageInfo
         :last_editors: HuangJianYi
         """
@@ -404,6 +405,9 @@ class AssetBaseModel():
         if source_type != 0:
             condition += " AND source_type=%s"
             params.append(source_type)
+        if operate_type != -1:
+            condition += " AND operate_type=%s"
+            params.append(operate_type)
         if source_object_id:
             if type(source_object_id) == str:
                 condition += " AND " + SevenHelper.get_condition_by_str_list("source_object_id",source_object_id.split(","))
