@@ -2,14 +2,13 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2021-12-17 10:52:01
+@LastEditTime: 2021-12-30 11:41:31
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.enum import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
-from seven_cloudapp_frame.models.seven_model import PageInfo
 from seven_cloudapp_frame.models.db_models.ip.ip_info_model import *
 
 
@@ -19,7 +18,7 @@ class IpBaseModel():
     """
     def __init__(self, context):
         self.context = context
-    
+
     def _delete_ip_info_dependency_key(self,act_id):
         """
         :description: 删除ip信息依赖建
@@ -95,32 +94,37 @@ class IpBaseModel():
         self._delete_ip_info_dependency_key(act_id)
         return invoke_result_data
 
-    def get_ip_info_list(self,app_id,act_id,page_size,page_index,order_by="sort_index desc",is_cache=True):
+    def get_ip_info_list(self, app_id, act_id, page_size, page_index, field="*", condition="", params=[], order_by="sort_index desc", is_cache=True):
         """
         :description: 获取IP列表
         :param app_id：应用标识
         :param act_id：活动标识
-        :param page_index：页索引
         :param page_size：页大小
+        :param page_index：页索引
+        :param field：字段
+        :param condition：条件
+        :param params：参数数组
         :param order_by：排序
         :param is_cache：是否缓存
         :return: list
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        params_list = [app_id, act_id]
+        condition_where = ConditionWhere()
+        condition_where.add_condition("app_id=%s and act_id=%s")
+        if condition:
+            condition_where.add_condition(condition)
+            params_list.extend(params)
         if is_cache == True:
-            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"ip_info_list:actid_{act_id}",cache_expire=600)
+            page_list, total = IpInfoModel(context=self.context).get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list, dependency_key=f"ip_info_list:actid_{act_id}", cache_expire=600)
         else:
-            page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field="*", page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+            page_list, total = IpInfoModel(context=self.context).get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition_where.to_string(), group_by="", order_by=order_by, params=params_list)
+        return page_list, total
 
-    def delete_ip_info(self,app_id,act_id,ip_id):
+    def delete_ip_info(self,app_id,ip_id):
         """
         :description: 删除ip
         :param app_id：应用标识
-        :param act_id：活动标识
         :param ip_id：ip标识
         :return: 
         :last_editors: HuangJianYi
@@ -128,21 +132,20 @@ class IpBaseModel():
         invoke_result_data = InvokeResultData()
         ip_info_model = IpInfoModel(context=self.context)
         ip_info_dict = ip_info_model.get_dict_by_id(ip_id)
-        if not ip_info_dict or ip_info_dict["act_id"]!=act_id or ip_info_dict["app_id"]!=app_id:
+        if not ip_info_dict or ip_info_dict["app_id"]!=app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-            
+
         invoke_result_data.success = ip_info_model.del_entity("id=%s", ip_id)
-        self._delete_ip_info_dependency_key(act_id)
+        self._delete_ip_info_dependency_key(ip_info_dict["act_id"])
         return invoke_result_data
 
-    def release_ip_info(self,app_id,act_id,ip_id,is_release):
+    def release_ip_info(self,app_id,ip_id,is_release):
         """
         :description: ip上下架
         :param app_id：应用标识
-        :param act_id：活动标识
         :param ip_id：ip标识
         :param is_release: 是否发布 1-是 0-否
         :return: 
@@ -151,12 +154,12 @@ class IpBaseModel():
         invoke_result_data = InvokeResultData()
         ip_info_model = IpInfoModel(context=self.context)
         ip_info_dict = ip_info_model.get_dict_by_id(ip_id)
-        if not ip_info_dict or ip_info_dict["act_id"]!=act_id or ip_info_dict["app_id"]!=app_id:
+        if not ip_info_dict or ip_info_dict["app_id"]!=app_id:
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-            
+
         invoke_result_data.success = ip_info_model.update_table("is_release=%s", "id=%s", [is_release, ip_id])
-        self._delete_ip_info_dependency_key(act_id)
+        self._delete_ip_info_dependency_key(ip_info_dict["act_id"])
         return invoke_result_data
\ No newline at end of file
