@@ -53,7 +53,7 @@ class LaunchBaseModel():
                     price_gear_total = PriceGearModel(context=self.context).get_total("act_id=%s and goods_id=%s", params=[act_id, old_goods_id])
                     if price_gear_total > 0 :
                         is_update = False
-            if is_update == True: 
+            if is_update == True:
                 launch_goods_model.update_table("is_launch=0,is_sync=0,launch_date=%s", "act_id=%s and goods_id=%s", params=[SevenHelper.get_now_datetime(), act_id, old_goods_id])
 
         total = launch_goods_model.get_total("act_id=%s and goods_id=%s", params=[act_id, goods_id])
@@ -144,7 +144,7 @@ class LaunchBaseModel():
 
         launch_goods_model = LaunchGoodsModel(context=self.context)
         goods_exist_list = launch_goods_model.get_dict_list("act_id<>%s and " + SevenHelper.get_condition_by_str_list("goods_id",goods_id_list), field="goods_id", params=act_id)
-        goods_id_exist_list = [i for i in goods_exist_list]
+        goods_id_exist_list = [str(i["goods_id"]) for i in goods_exist_list]
         goods_list = []
         now_datetime = SevenHelper.get_now_datetime()
         for goods_id in goods_id_list:
@@ -153,11 +153,11 @@ class LaunchBaseModel():
             launch_goods.act_id = act_id
             launch_goods.goods_id = goods_id
             if goods_id in goods_id_exist_list:
-                 launch_goods.is_launch = 0
-                 launch_goods.is_sync = 0
+                launch_goods.is_launch = 0
+                launch_goods.is_sync = 0
             else:
-                 launch_goods.is_launch = 1
-                 launch_goods.is_sync = 1
+                launch_goods.is_launch = 1
+                launch_goods.is_sync = 1
 
             launch_goods.create_date = now_datetime
             launch_goods.launch_date = now_datetime
@@ -205,16 +205,16 @@ class LaunchBaseModel():
             # 淘宝top接口
             invoke_result_data = top_base_model.miniapp_distribution_items_bind(no_launch_goods_ids, online_url, 'false',access_token,app_key, app_secret, is_log)
             if invoke_result_data.success == False:
-                 invoke_result_data.success = False
-                 invoke_result_data.error_code = "error"
-                 invoke_result_data.error_message = "活动不存在"
-                 return invoke_result_data
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "活动不存在"
+                return invoke_result_data
             resp = invoke_result_data.data
             if "error_message" in resp.keys():
-                 invoke_result_data.success = False
-                 invoke_result_data.error_code = "error"
-                 invoke_result_data.error_message = resp["error_message"]
-                 return invoke_result_data
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = resp["error_message"]
+                return invoke_result_data
             async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
             for async_result_info in async_result:
                 no_launch_goods = [no_launch_goods for no_launch_goods in no_launch_goods_list if str(no_launch_goods.goods_id) == async_result_info["target_entity_id"]]
@@ -238,16 +238,16 @@ class LaunchBaseModel():
             # 淘宝top接口
             invoke_result_data = top_base_model.miniapp_distribution_items_bind(launch_goods_ids, online_url, 'true',access_token,app_key, app_secret, is_log)
             if invoke_result_data.success == False:
-                 invoke_result_data.success = False
-                 invoke_result_data.error_code = "error"
-                 invoke_result_data.error_message = "活动不存在"
-                 return invoke_result_data
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = "活动不存在"
+                return invoke_result_data
             resp = invoke_result_data.data
             if "error_message" in resp.keys():
-                 invoke_result_data.success = False
-                 invoke_result_data.error_code = "error"
-                 invoke_result_data.error_message = resp["error_message"]
-                 return invoke_result_data
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "error"
+                invoke_result_data.error_message = resp["error_message"]
+                return invoke_result_data
             async_result = resp["miniapp_distribution_items_bind_response"]["model_list"]["distribution_order_bind_target_entity_open_result_dto"][0]["bind_result_list"]["distribution_order_bind_base_dto"]
             for async_result_info in async_result:
                 launch_goods = [launch_goods for launch_goods in launch_goods_list if str(launch_goods.goods_id) == async_result_info["target_entity_id"]]
@@ -262,7 +262,7 @@ class LaunchBaseModel():
                     update_launch_goods_list.append(launch_goods[0])
 
             launch_goods_model.update_list(update_launch_goods_list)
-        
+
         return invoke_result_data
 
     def get_launch_goods_list(self, app_id, act_id, page_size, page_index, access_token, app_key, app_secret):
@@ -288,16 +288,16 @@ class LaunchBaseModel():
             return invoke_result_data
         launch_goods_model = LaunchGoodsModel(context=self.context)
         launch_goods_list, total = launch_goods_model.get_dict_page_list("*", page_index, page_size, "app_id=%s and act_id=%s", "", "id desc", params=[app_id,act_id])
-        
+
         top_base_model = TopBaseModel(context=self.context)
         #获取商品信息
         goods_list = []
         if len(launch_goods_list) > 0:
             goods_ids = ",".join([str(launch_goods["goods_id"]) for launch_goods in launch_goods_list])
-            
+
             invoke_result_data = top_base_model.get_goods_list_by_goodsids(goods_ids, access_token,app_key,app_secret)
             if invoke_result_data.success == False:
-                 return invoke_result_data
+                return invoke_result_data
             resq = invoke_result_data.data
             if "items_seller_list_get_response" in resq.keys():
                 if "item" in resq["items_seller_list_get_response"]["items"].keys():
