@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-01-10 16:14:47
+@LastEditTime: 2022-01-11 14:21:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -293,13 +293,14 @@ class StatBaseModel(FrameBaseModel):
 
         return common_group_data_list
 
-    def process_invite_report(self,app_id,act_id,module_id,user_id,login_token,invite_user_id,handler_name,check_user_nick=True,continue_request_expire=5,is_stat=True):
+    def process_invite_report(self,app_id,act_id,module_id,user_id,open_id,login_token,invite_user_id,handler_name,check_user_nick=True,continue_request_expire=5,is_stat=True):
         """
         :description: 处理邀请进入上报
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
         :param user_id:用户标识
+        :param open_id:open_id
         :param login_token:访问令牌
         :param invite_user_id:邀请人用户标识
         :param handler_name:接口名称
@@ -319,21 +320,20 @@ class StatBaseModel(FrameBaseModel):
                 invoke_result_data.error_code = "error"
                 invoke_result_data.error_message = "无效邀请"
                 return invoke_result_data
-
-            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,False,check_user_nick,continue_request_expire,acquire_lock_name)
+            stat_base_model = StatBaseModel(context=self.context)
+            key_list_dict = {}
+            invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,True,check_user_nick,continue_request_expire,acquire_lock_name)
             if invoke_result_data.success == True:
                 act_info_dict = invoke_result_data.data["act_info_dict"]
                 act_module_dict = invoke_result_data.data["act_module_dict"]
                 user_info_dict = invoke_result_data.data["user_info_dict"]
                 identifier = invoke_result_data.data["identifier"]
                 if is_stat == True:
-                    stat_base_model = StatBaseModel(context=self.context)
-                    key_list_dict = {}
                     key_list_dict["AddBeInvitedUserCount"] = 1 #从分享进入新增用户数
-                    key_list_dict["BeInvitedUserCount"] = 1 #从分享进入用户数
-                    key_list_dict["BeInvitedCount"] = 1 #从分享进入次数
-                    stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
-
+            if is_stat == True:
+                key_list_dict["BeInvitedUserCount"] = 1  #从分享进入用户数
+                key_list_dict["BeInvitedCount"] = 1  #从分享进入次数
+                stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
         except Exception as ex:
             self.context.logging_link_error("【处理邀请上报】" + traceback.format_exc())
             invoke_result_data.success = False
